//****************************************************************************
// File: runtask.c
//
// Purpose: private task to own runlib's toolhelp callback proc
//
// Functions: WinMain
//
//
// Development Team: richhe
//
//
// Written by Microsoft Product Support Services, Windows Developer Support
// Copyright (c) 1992 Microsoft Corporation. All rights reserved.
//****************************************************************************

#include <windows.h>
#include <toolhelp.h>
#include <memory.h>
#include "runlib.h"

//***********************************************************************
// Function: WinMain
//
// Purpose: C entry point of application. Registers callback and waits for
//          WM_QUIT posted from runlib's WEP procedure
//
// Parameters:
//          HINSTANCE hInst;     instance handle of application
//          HINSTANCE hPrevInst; instance handle of previous instance
//          LPSTR lpszCmdLine;   command line
//          int nCmdShow;        initial show window value
//
// Returns:
//
// Comments:
//
// History:  Date       Author        Reason
//
//****************************************************************************

int PASCAL WinMain(HINSTANCE hInst, HINSTANCE hPrevInst, LPSTR lpszCmdLine, int nCmdShow)
{
  MSG                msg;
  HINSTANCE          hModule;
  LPFNNOTIFYCALLBACK lpfnCallback;
  LPHOOKPROC         lpHookProc;
  BOOL               bInstalled;

  // let runlib load, better release control
  
  Yield();

  // if runlib loaded, then do more

  hModule = GetModuleHandle("RUNLIB");
  if(hModule != NULL)
  {

  // get the callback procedure address from runlib

     lpfnCallback = (LPFNNOTIFYCALLBACK) GetProcAddress(hModule, MAKEINTRESOURCE(NOTIFYPROC));
     if( lpfnCallback != NULL )
     {

  // if its sucessfull, try to chain into TOOLHELP's stuff

        bInstalled = NotifyRegister(NULL, lpfnCallback, NF_NORMAL);
        if(bInstalled != FALSE)
        {

  // if TOOLHELP was happy, then get runlib procdure to inform it

           lpHookProc = (LPHOOKPROC) GetProcAddress(hModule, MAKEINTRESOURCE(HOOKPROC));
           if(lpHookProc != NULL)
           {

  // tell runlib that register was sucessful

              bInstalled = lpHookProc();

  // wait around for WM_QUIT posted from RunLib's WEP

              while(GetMessage(&msg, 0,0,0))  
              {
                 TranslateMessage(&msg);
                 DispatchMessage(&msg);
              }
           }
        }
     }
  }
  return(0);
}



